@@ -1,5 +1,6 @@
 from django.conf import settings
 from django.http import HttpResponsePermanentRedirect
+from django.core.urlresolvers import reverse
 
 
 class SSLifyAdminMiddleware(object):
@@ -11,8 +12,8 @@ class SSLifyAdminMiddleware(object):
     """
 
     def process_request(self, request):
-        sslify_admin_url = getattr(settings, 'SSLIFY_ADMIN_URL', 'admin/')
-        if request.path.startswith('/' + sslify_admin_url) and \
+        sslify_admin_namespace = getattr(settings, 'SSLIFY_ADMIN_NAMESPACE', 'admin')
+        if request.path.startswith(reverse('%s:index' % sslify_admin_namespace)) and \
                 not (settings.DEBUG or request.is_secure()):
             url = request.build_absolute_uri(request.get_full_path())
             secure_url = url.replace('http://', 'https://')
